DeviceAvailable class

Similar to your DeviceAvailableEvent payload

Constructors

DeviceAvailable({required bool available, bool offline = false, required String lastStatus})

Properties

available bool
final
hashCode int
The hash code for this object.
no setterinherited
lastStatus String
final
offline bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited