SerialPrintQueue class

Constructors

SerialPrintQueue(SerialPortHandler sp, {Duration timeout = const Duration(seconds: 2), Duration quietWindow = const Duration(milliseconds: 150), bool stripFraming = true, ResponseClassifier? classifier})

Properties

classify ResponseClassifier
final
hashCode int
The hash code for this object.
no setterinherited
quietWindow Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sp SerialPortHandler
final
stripFraming bool
final
timeout Duration
final

Methods

enqueue(Uint8List requestBytes) Future<PrintResult>
Enqueue request; returns classified result.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printBytes(Uint8List bytes) Future<PrintResult>
Enqueue raw bytes.
printText(String data) Future<PrintResult>
Enqueue a text print (sends as UTF-8).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited