DeviceStatus class
Constructors
- DeviceStatus()
-
DeviceStatus.fromJson(Map<
String, dynamic> json) -
factory
Properties
- desc ↔ String
-
getter/setter pair
- diskError ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- headLifted ↔ bool
-
getter/setter pair
- init ↔ bool
-
getter/setter pair
- maxWeightExceeded ↔ bool
-
getter/setter pair
- notExist ↔ bool
-
getter/setter pair
- paperJam ↔ bool
-
getter/setter pair
- paperOut ↔ bool
-
getter/setter pair
- powerOff ↔ bool
-
getter/setter pair
- ready ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ StatusState
-
getter/setter pair
- unknown ↔ bool
-
getter/setter pair
Methods
-
clone(
) → DeviceStatus -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited