StatusManager class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → DeviceStatus
-
no setter
-
statusNotifier
→ ValueNotifier<
DeviceStatus> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateFrom(
String statusString, {required bool sqni}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited